@@ -6,6 +6,14 @@
 NULL
 
 
+isSpark <- function(db) {
+  if(is.null(db)) {
+    return(FALSE)
+  }
+  length(intersect(c("spark_connection", "spark_shell_connection"),
+            class(db)))>0
+}
+
 
 listFields <- function(my_db, tableName) {
   # fails intermitnently, and sometimes gives wrong results
@@ -251,10 +259,18 @@ rowrecs_to_blocks_q <- function(wideTable,
   }
   ctabName <- tempNameGenerator()
   rownames(controlTable) <- NULL # just in case
-  DBI::dbWriteTable(my_db,
-                    ctabName,
-                    controlTable,
-                    temporary = TRUE)
+  if(!isSpark(my_db)) {
+    DBI::dbWriteTable(my_db,
+                      ctabName,
+                      controlTable,
+                      overwrite = TRUE,
+                      temporary = TRUE)
+  } else {
+    DBI::dbWriteTable(my_db,
+                      ctabName,
+                      controlTable,
+                      temporary = TRUE)
+  }
   if(is.null(resultName)) {
     resName <- tempNameGenerator()
   } else {
@@ -392,6 +408,7 @@ rowrecs_to_blocks <- function(wideTable,
   if(length(list(...))>0) {
     stop("cdata::rowrecs_to_blocks unexpected arguments.")
   }
+  wtname <- "cata_wide_tmp"
   need_close <- FALSE
   db_handle <- base::mget("winvector_temp_db_handle",
                           envir = env,
@@ -404,12 +421,19 @@ rowrecs_to_blocks <- function(wideTable,
     my_db <- db_handle$db
   }
   rownames(wideTable) <- NULL # just in case
-  DBI::dbWriteTable(my_db,
-                    'wideTable',
-                    wideTable,
-                    overwrite = FALSE,
-                    temporary = TRUE)
-  resName <- rowrecs_to_blocks_q(wideTable = 'wideTable',
+  if(!isSpark(my_db)) {
+    DBI::dbWriteTable(my_db,
+                      wtname,
+                      wideTable,
+                      overwrite = TRUE,
+                      temporary = TRUE)
+  } else {
+    DBI::dbWriteTable(my_db,
+                      wtname,
+                      wideTable,
+                      temporary = TRUE)
+  }
+  resName <- rowrecs_to_blocks_q(wideTable = wtname,
                                  controlTable = controlTable,
                                  my_db = my_db,
                                  columnsToCopy = columnsToCopy,
@@ -419,7 +443,7 @@ rowrecs_to_blocks <- function(wideTable,
                                  showQuery = showQuery,
                                  defaultValue = defaultValue)
   resData <- DBI::dbGetQuery(my_db, paste("SELECT * FROM", resName))
-  x <- DBI::dbExecute(my_db, paste("DROP TABLE", 'wideTable'))
+  x <- DBI::dbExecute(my_db, paste("DROP TABLE", wtname))
   x <- DBI::dbExecute(my_db, paste("DROP TABLE", resName))
   if(need_close) {
     DBI::dbDisconnect(my_db)
@@ -536,19 +560,27 @@ build_pivot_control <- function(table,
   } else {
     my_db <- db_handle$db
   }
+  ptabtmpnam <- "cdata_build_pc_tmp"
   rownames(table) <- NULL # just in case
-  DBI::dbWriteTable(my_db,
-                    'stable',
-                    table,
-                    overwrite = FALSE,
-                    temporary = TRUE)
-  res <- build_pivot_control_q(tableName = 'stable',
+  if(!isSpark(my_db)) {
+    DBI::dbWriteTable(my_db,
+                      ptabtmpnam,
+                      table,
+                      overwrite = TRUE,
+                      temporary = TRUE)
+  } else {
+    DBI::dbWriteTable(my_db,
+                      ptabtmpnam,
+                      table,
+                      temporary = TRUE)
+  }
+  res <- build_pivot_control_q(tableName = ptabtmpnam,
                                columnToTakeKeysFrom = columnToTakeKeysFrom,
                                columnToTakeValuesFrom = columnToTakeValuesFrom,
                                my_db = my_db,
                                prefix = prefix,
                                sep = sep)
-  x <- DBI::dbExecute(my_db, paste("DROP TABLE", 'stable'))
+  x <- DBI::dbExecute(my_db, paste("DROP TABLE", ptabtmpnam))
   if(need_close) {
     DBI::dbDisconnect(my_db)
   }
@@ -670,10 +702,18 @@ blocks_to_rowrecs_q <- function(tallTable,
   }
   ctabName <- tempNameGenerator()
   rownames(controlTable) <- NULL # just in case
-  DBI::dbWriteTable(my_db,
-                    ctabName,
-                    controlTable,
-                    temporary = TRUE)
+  if(!isSpark(my_db)) {
+    DBI::dbWriteTable(my_db,
+                      ctabName,
+                      controlTable,
+                      overwrite = TRUE,
+                      temporary = TRUE)
+  } else {
+    DBI::dbWriteTable(my_db,
+                      ctabName,
+                      controlTable,
+                      temporary = TRUE)
+  }
   if(is.null(resultName)) {
     resName <- tempNameGenerator()
   } else {
@@ -847,13 +887,21 @@ blocks_to_rowrecs <- function(tallTable,
   } else {
     my_db <- db_handle$db
   }
+  talltbltmpnam <- "cdata_tall_tmp"
   rownames(tallTable) <- NULL # just in case
-  DBI::dbWriteTable(my_db,
-                    'tallTable',
-                    tallTable,
-                    temporary = TRUE,
-                    overwrite = FALSE)
-  resName <- blocks_to_rowrecs_q(tallTable = 'tallTable',
+  if(!isSpark(my_db)) {
+    DBI::dbWriteTable(my_db,
+                      talltbltmpnam,
+                      tallTable,
+                      temporary = TRUE,
+                      overwrite = TRUE)
+  } else {
+    DBI::dbWriteTable(my_db,
+                      talltbltmpnam,
+                      tallTable,
+                      temporary = TRUE)
+  }
+  resName <- blocks_to_rowrecs_q(tallTable = talltbltmpnam,
                                  keyColumns = keyColumns,
                                  controlTable = controlTable,
                                  my_db = my_db,
@@ -865,7 +913,7 @@ blocks_to_rowrecs <- function(tallTable,
                                  defaultValue = defaultValue,
                                  dropDups = dropDups)
   resData <- DBI::dbGetQuery(my_db, paste("SELECT * FROM", resName))
-  x <- DBI::dbExecute(my_db, paste("DROP TABLE", 'tallTable'))
+  x <- DBI::dbExecute(my_db, paste("DROP TABLE", talltbltmpnam))
   x <- DBI::dbExecute(my_db, paste("DROP TABLE", resName))
   if(need_close) {
     DBI::dbDisconnect(my_db)
